Method: HTML5::InitialPhase#process_eof

Defined in:
lib/html5/html5parser/initial_phase.rb

#process_eofObject

This phase deals with error handling as well which is currently not covered in the specification. The error handling is typically known as “quirks mode”. It is expected that a future version of HTML5 will define this.



10
11
12
13
14
# File 'lib/html5/html5parser/initial_phase.rb', line 10

def process_eof
  parse_error("expected-doctype-but-got-eof")
  @parser.phase = @parser.phases[:rootElement]
  @parser.phase.process_eof
end